@@ -13,7 +13,7 @@ parser.add_argument("-f", "--file", help="file to interpret")
 parser.add_argument("-v", "--version", action="store_true", help="show version")
 args = parser.parse_args()
 
-ver = "1.11.5"
+ver = "1.11.7"
 
 run = True
 
@@ -28,7 +28,7 @@ help = """
 7 <- Function Def
 % <- comment
 ^number[+\-\/\*\#]number <- Math-Operation-Start
-?condition:True:False <- If-Else
+?condition|True|False <- If-Else
 """
 
 space = ""
